@@ -5,19 +5,19 @@ points.predMexhaz <- function(x,which=c("surv","hazard"),conf.int=TRUE,lty.pe="s
     }
     time.pts <- x$results$time.pts
     if (which=="hazard"){
-        points(time.pts,x$results$hazard,type="l",lty=lty.pe,...)
+        points(time.pts,x$results$hazard,lty=lty.pe,...)
     }
     else {
-        points(c(0,time.pts),c(1,x$results$surv),type="l",lty=lty.pe,...)
+        points(c(0,time.pts),c(1,x$results$surv),lty=lty.pe,...)
     }
     if (conf.int==TRUE & x$ci.method!="none"){
         if (which=="hazard"){
-            points(time.pts,x$results$hazard.inf,type="l",lty=lty.ci,...)
-            points(time.pts,x$results$hazard.sup,type="l",lty=lty.ci,...)
+            points(time.pts,x$results$hazard.inf,lty=lty.ci,...)
+            points(time.pts,x$results$hazard.sup,lty=lty.ci,...)
         }
         else {
-            points(c(0,time.pts),c(1,x$results$surv.inf),type="l",lty=lty.ci,...)
-            points(c(0,time.pts),c(1,x$results$surv.sup),type="l",lty=lty.ci,...)
+            points(c(0,time.pts),c(1,x$results$surv.inf),lty=lty.ci,...)
+            points(c(0,time.pts),c(1,x$results$surv.sup),lty=lty.ci,...)
         }
     }
 }
